# BerryEasy

BerryEasy is a python package developed by Alex Tyner. It expands upon the powerful pybinding code, offering functionality for computing topological properties of Pybinding instances as well as creating  Pybinding instances from the output of Wannier90. 

## Capabilities of BerryEasy

Computation of: Wannier center charges, Spin-resolved Wannier center charges, Nested wilson loop computations, conversion of Wannier90 output to pybinding format

### For comments, questions or to report a bug email alextyner at gmail.com
